@@ -12,10 +12,10 @@ def tomlrc(*path, filename="~/.tomlrc"):
     with open(filename, "rb") as f:
         toml = tomllib.load(f)
 
-    if section is None:
+    if path is None:
         return toml
     else:
-        for key in section:
+        for key in path:
             toml = toml[key]
 
         return toml
